@@ -40,13 +40,11 @@
 ##' @author Klaus K. Holst
 ##' @export
 ##' @examples
-##' \donttest{
 ##' data(twinstut)
 ##' b0 <- bptwin(stutter~sex,
 ##'              data=droplevels(subset(twinstut,zyg%in%c("mz","dz"))),
 ##'              id="tvparnr",zyg="zyg",DZ="dz",type="ae")
 ##' summary(b0)
-##' }
 bptwin <- function(x, data, id, zyg, DZ, group=NULL,
                    num=NULL,
                    weights=NULL,
@@ -109,7 +107,7 @@ bptwin <- function(x, data, id, zyg, DZ, group=NULL,
       if (!samecens & !is.null(weights)) {
         control$method <- "bhhh"
       } else {
-        if (suppressWarnings(suppressPackageStartupMessages(require(ucminf)))) {
+        if (requireNamespace("ucminf",quietly=TRUE)) {
           control$method <- "gradient"
         } else control$method <- "nlminb"
       }
