@@ -19,6 +19,8 @@
 ##' library(lava)
 ##' m <- lvm(c(y1,y2,y3,y4)~x)
 ##' d <- sim(m,5)
+##' d
+##' fast.reshape(d,"y")
 ##' fast.reshape(fast.reshape(d,"y"),id="id")
 ##' 
 ##' ##### From wide-format
@@ -37,6 +39,7 @@
 ##' 
 ##' #####
 ##' x <- data.frame(id=c(5,5,6,6,7),y=1:5,x=1:5,tv=c(1,2,2,1,2))
+##' x
 ##' (xw <- fast.reshape(x,id="id"))
 ##' (xl <- fast.reshape(xw,c("y","x"),idname="id2",keep=c()))
 ##' (xl <- fast.reshape(xw,c("y","x","tv")))
@@ -58,6 +61,7 @@
 ##' ##'
 ##' 
 ##' d <- sim(lvm(~y1+y2+ya),10)
+##' d
 ##' (dd <- fast.reshape(d,"y"))
 ##' fast.reshape(d,"y",labelnum=TRUE)
 ##' fast.reshape(dd,id="id",num="num")
@@ -77,7 +81,6 @@
 ##' ##### Automatically define varying variables from trailing digits
 ##' fast.reshape(d)
 ##' 
-##' 
 ##' ##### Prostate cancer example
 ##' data(prt)
 ##' head(prtw <- fast.reshape(prt,"cancer",id="id"))
@@ -194,7 +197,14 @@ fast.reshape <- function(data,varying,id,num,sep="",keep,
             if (!is.null(names(vnames))) vnames <- names(vnames)
         }
 
-        if (oldreshape) return(reshape(as.data.frame(data),varying=varying,direction="long",v.names=vnames,timevar=numname,idvar=idname,...)) ### Fall-back to stats::reshape
+        if (oldreshape) {
+            ## Fall-back to stats::reshape
+            return(
+                structure(reshape(as.data.frame(data),varying=varying,direction="long",v.names=vnames,timevar=numname,idvar=idname,...),
+                          class=c("fast.reshape","data.frame"),
+                          direction="wide",
+                          varying=varying))
+        }
 
         fixed <- setdiff(nn,unlist(c(varying,numname)))
         if (!missing(keep)) fixed <- intersect(fixed,c(keep,idname,numname))
@@ -245,7 +255,11 @@ fast.reshape <- function(data,varying,id,num,sep="",keep,
                 long[,vars.new[i]] <- base::factor(long[,vars.new[i]],levels=lev[[count]])
             }
         }
-        return(long)
+        return(
+            structure(long,
+                      class=c("fast.reshape","data.frame"),
+                      type="wide",
+                      varying=varying))
     }
 
 
@@ -339,7 +353,8 @@ fast.reshape <- function(data,varying,id,num,sep="",keep,
                         as.vector(t(outer(postn,varying,function(x,y) paste(y,x,sep=sep)))))      
         }
         colnames(dataw) <- mnames
-        return(as.data.frame(dataw))
+        return(structure(as.data.frame(dataw),class=c("fast.reshape","data.frame"),
+                         varying=varying,direction="long"))
     }
 
     ## Potentially slower with data.frame where we use cbind
@@ -360,11 +375,11 @@ fast.reshape <- function(data,varying,id,num,sep="",keep,
                 mnames <- c(mnames,paste(varying,sep,i,sep=""))
         }
     }
-    names(dataw) <- mnames    
-    return(dataw)
+    names(dataw) <- mnames
+    return(structure(dataw,class=c("fast.reshape","data.frame"),
+                     varying=varying,type="long"))
 } 
 
-
 simple.reshape <- function (data, id = "id", num = NULL) {
     cud <- cluster.index(data[, c(id)], num = num, Rindex = 1)
     N <- nrow(cud$idclust)
