@@ -1,6 +1,6 @@
-'.onAttach' <- function(lib, pkg="mets")
+'.onAttach' <- function(libname, pkgname="mets")
   {    
-    desc <- packageDescription(pkg)
+    desc <- utils::packageDescription(pkgname)
     ## packageStartupMessage("Loading '", desc$Package, "' package...\n",
     ##                       "\tVersion: ", desc$Version, "\n",
     ##                       "\tOverview: help(package=", desc$Package, ")");
